wk-20200101

Workiva 2024-07-25 iso4217:EUR 123456 2020-01-01 2020-03-31 123456 2020-03-31
12
Workiva
01/01/2020
EntityCurrentLegalOrRegisteredName
01/01/2019
12344
10 DPLGovernmentGrantIncome
5 DPLOtherOperatingIncome, i
10 DPLProfitLossBeforeTax,
11 DPLStaffCostsEmployeeBenefitsExpense,
1 DPLSubcontractorCosts,
1 3 DPLTurnoverRevenue.
5 Equity
1111 DPLGrossProfitLoss
Euro PrincipalCurrencyUsedInBusinessReport